@@ -23,7 +23,7 @@ package Sys::Filesystem::Mswin32;
 
 # vim:ts=4:sw=4:tw=78
 
-use 5.008003;
+use 5.008001;
 
 use strict;
 use warnings;
@@ -33,16 +33,24 @@ use Params::Util qw(_STRING);
 use Win32::DriveInfo;
 use Carp qw(croak);
 
-$VERSION = '1.403';
+$VERSION = '1.404';
 
 sub version()
 {
     return $VERSION;
 }
 
-my @volInfoAttrs =
-  ( 'n/a', 'preserve case', 'case sensitive', 'unicode', 'acl', 'file compression', 'compressed volume' );
-my @typeExplain = ( 'not determined', 'not available', 'removeable', 'fixed', 'network', 'cdrom', 'ram disk' );
+my @volInfoAttrs = (
+                     'n/a',
+                     'preserve case',
+                     'case sensitive',
+                     'unicode',
+                     'acl',
+                     'file compression',
+                     'compressed volume'
+                   );
+my @typeExplain =
+  ( 'not determined', 'not available', 'removeable', 'fixed', 'network', 'cdrom', 'ram disk' );
 
 sub new
 {
@@ -71,9 +79,11 @@ sub new
 
         $FileSystemName ||= 'CDFS' if ( $type == 5 );
 
-        $self->{$drvRoot}->{mount_point} = $drvRoot;        # XXX Win32::DriveInfo gives no details here ...
-        $self->{$drvRoot}->{device}      = $VolumeName;
-        $self->{$drvRoot}->{format}      = $FileSystemName; # XXX Win32::DriveInfo gives sometime wrong information here
+        $self->{$drvRoot}->{mount_point} =
+          $drvRoot;    # XXX Win32::DriveInfo gives no details here ...
+        $self->{$drvRoot}->{device} = $VolumeName;
+        $self->{$drvRoot}->{format} =
+          $FileSystemName;    # XXX Win32::DriveInfo gives sometime wrong information here
         $self->{$drvRoot}->{options} = join( ',', map { $volInfoAttrs[$_] } @attr );
         if ( $self->{$drvRoot}->{mounted} = $type > 1 )
         {
